@@ -124,11 +124,6 @@ class FlywayConstruct(
     def ID_LAMBDA_CODE(cls) -> builtins.str:
         return typing.cast(builtins.str, jsii.sget(cls, "ID_LAMBDA_CODE"))
 
-    @jsii.python.classproperty # type: ignore[misc]
-    @jsii.member(jsii_name="OBJECT_CODE_KEY")
-    def OBJECT_CODE_KEY(cls) -> builtins.str:
-        return typing.cast(builtins.str, jsii.sget(cls, "OBJECT_CODE_KEY"))
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="flywayLambdaMigration")
     def flyway_lambda_migration(self) -> aws_cdk.aws_lambda.Function:
@@ -138,6 +133,15 @@ class FlywayConstruct(
     def flyway_lambda_migration(self, value: aws_cdk.aws_lambda.Function) -> None:
         jsii.set(self, "flywayLambdaMigration", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="objectCodeKey")
+    def object_code_key(self) -> typing.Any:
+        return typing.cast(typing.Any, jsii.get(self, "objectCodeKey"))
+
+    @object_code_key.setter
+    def object_code_key(self, value: typing.Any) -> None:
+        jsii.set(self, "objectCodeKey", value)
+
 
 @jsii.data_type(
     jsii_type="flywaymigrationconstruct.FlywayConstructParams",
